==> nodebright-ext-highlight-widget-1.0.2.tgz: package/index.js <==
"use strict";

var path = require('path');
var url = require("url");
var util = require('util');
var fs = require('fs');
var _ = require('underscore');
var winston = require('winston');
var emitter = require(path.join(LIBS_DIR, 'eventEmitter'));
var option = require(path.join(LIBS_DIR, 'option'));
var service = require(path.join(LIBS_DIR, 'service'));
var post = require(path.join(LIBS_DIR, 'post'));
var extension = require(path.join(LIBS_DIR, 'extension'));
var router = require(path.join(LIBS_DIR, 'router.js'))();
var g = require(path.join(LIBS_DIR, 'global'));

var mdl = {};
module.exports = function(moduleName, req, res)  {
    var self = {};

    self.initHighlightWidgetExt = function(nb) {
        mdl = new extension(req, res, __dirname);
        emitter.emit('ext:highlight_widget:init');
        service.registerWidget('highlight', {
            label: lang('Highlight posts'),
            ext: path.basename(__dirname),
            config: {
                right_count: {
                    label: lang('Side posts number'),
                    type: 'String',
                    display: 'input',
                    position: 'common',
                    cols: 12
                },
                total_count: {
                    label: lang('Total posts number'),
                    type: 'String',
                    display: 'input',
                    position: 'common',
                    cols: 12
                }
            },
            templates: {
                'default': lang('Default'),
                'bordered': lang('Bordered')
            },
            render: 'output'
        });
        emitter.emit('ext:highlight_widget:initCompleted');
    };

    self.output = function(wdData) {
        return new Promise(function(resolve, reject) {
            var headlinePosts = (g.working.taxonomy) ? option.get('headline_posts')['sub_' + g.working.taxonomy.intId] : option.get('headline_posts').main;
            wdData.postProvider = post.getPostByIds(headlinePosts, 7);
            wdData.headlinePosts = headlinePosts;
            mdl.singleRender(wdData.template, wdData, function(err, dps, data) {
                if(err) reject(err);
                else resolve(data);
            });
        });
    };

    return self;
};

==> nodebright-ext-highlight-widget-1.0.3.tgz: package/index.js <==
"use strict";

var path = require('path');
var url = require("url");
var util = require('util');
var fs = require('fs');
var _ = require('underscore');
var winston = require('winston');
var emitter = require(path.join(LIBS_DIR, 'eventEmitter'));
var option = require(path.join(LIBS_DIR, 'option'));
var service = require(path.join(LIBS_DIR, 'service'));
var post = require(path.join(LIBS_DIR, 'post'));
var extension = require(path.join(LIBS_DIR, 'extension'));
var router = require(path.join(LIBS_DIR, 'router.js'))();
var g = require(path.join(LIBS_DIR, 'global'));

var mdl = {};
module.exports = function(moduleName, req, res)  {
    var self = {};

    self.initHighlightWidgetExt = function(nb) {
        mdl = new extension(req, res, __dirname);
        emitter.emit('ext:highlight_widget:init');
        service.registerWidget('highlight', {
            label: lang('Highlight posts'),
            ext: path.basename(__dirname),
            config: {
                right_count: {
                    label: lang('Side posts number'),
                    type: 'String',
                    display: 'input',
                    position: 'common',
                    cols: 12
                },
                total_count: {
                    label: lang('Total posts number'),
                    type: 'String',
                    display: 'input',
                    position: 'common',
                    cols: 12
                }
            },
            templates: {
                'default': lang('Default'),
                'bordered': lang('Bordered')
            },
            render: 'output'
        });
        emitter.emit('ext:highlight_widget:initCompleted');
    };

    self.output = function(wdData) {
        return new Promise(function(resolve, reject) {
            var dbHeadlinePosts = option.get('headline_posts') ? option.get('headline_posts') : {main: []};
            var mainHeadlinePosts = dbHeadlinePosts.main ? dbHeadlinePosts.main : [];
            var headlinePosts = mainHeadlinePosts;

            if(g.working.taxonomy) {
                if(dbHeadlinePosts['sub_' + g.working.taxonomy.intId])
                    headlinePosts = dbHeadlinePosts['sub_' + g.working.taxonomy.intId];
                else headlinePosts = [];
            }
            wdData.postProvider = post.getPostByIds(headlinePosts, 7);
            wdData.headlinePosts = headlinePosts;
            mdl.singleRender(wdData.template, wdData, function(err, dps, data) {
                if(err) reject(err);
                else resolve(data);
            });
        });
    };

    return self;
};
